import React, { createContext, useRef, useState, useCallback, useMemo, useContext, useReducer, useEffect } from 'react';
import styled, { keyframes, css } from 'styled-components';

/* External dependencies */
var ContainerRefContext = createContext(null);

function _typeof(obj) {
  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
    _typeof = function (obj) {
      return typeof obj;
    };
  } else {
    _typeof = function (obj) {
      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };
  }

  return _typeof(obj);
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(source, true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(source).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};

  var target = _objectWithoutPropertiesLoose(source, excluded);

  var key, i;

  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }

  return target;
}

function _taggedTemplateLiteral(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }

  return Object.freeze(Object.defineProperties(strings, {
    raw: {
      value: Object.freeze(raw)
    }
  }));
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance");
}

function _templateObject() {
  var data = _taggedTemplateLiteral(["\n  height: 100%;\n  padding: 8px 0;\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}
var Wrapper = styled.div(_templateObject());

/* External dependencies */

function ContainerRefProvider(_ref) {
  var className = _ref.className,
      children = _ref.children;
  var wrapperRef = useRef(null);
  return React.createElement(Wrapper, {
    className: className,
    ref: wrapperRef
  }, React.createElement(ContainerRefContext.Provider, {
    value: wrapperRef
  }, children));
}

/* External dependencies */
var FormContext = createContext({
  values: {},
  updateInput: function updateInput() {},
  removeInput: function removeInput() {},
  submit: function submit() {},
  submitting: false
});

function FormProvider(_ref) {
  var _ref$submitting = _ref.submitting,
      submitting = _ref$submitting === void 0 ? false : _ref$submitting,
      onSubmit = _ref.onSubmit,
      children = _ref.children;

  var _useState = useState({}),
      _useState2 = _slicedToArray(_useState, 2),
      values = _useState2[0],
      setValues = _useState2[1];

  var valuesRef = useRef(values);
  var updateValues = useCallback(function (inputValues) {
    valuesRef.current = inputValues;
    setValues(inputValues);
  }, []);
  var updateInput = useCallback(function (id, value) {
    updateValues(_objectSpread2({}, valuesRef.current, _defineProperty({}, id, value)));
  }, [updateValues]);
  var removeInput = useCallback(function (id) {
    if (valuesRef.current[id]) {
      delete valuesRef.current[id];
    }

    updateValues(_objectSpread2({}, valuesRef.current));
  }, [updateValues]);
  var submit = useCallback(function (componentId) {
    if (onSubmit) {
      onSubmit(valuesRef.current, componentId);
    }
  }, [onSubmit]);
  var value = useMemo(function () {
    return {
      values: values,
      updateInput: updateInput,
      removeInput: removeInput,
      submit: submit,
      submitting: submitting
    };
  }, [values, updateInput, removeInput, submit, submitting]);
  return React.createElement(FormContext.Provider, {
    value: value
  }, children);
}

/* Internal dependencies */

var ActionType;

(function (ActionType) {
  ActionType["Submit"] = "submit";
  ActionType["URL"] = "url";
})(ActionType || (ActionType = {}));

var ActionType$1 = ActionType;

// eslint-disable-next-line @typescript-eslint/no-explicit-any
function isString(value) {
  return typeof value === 'string';
}

// eslint-disable-next-line @typescript-eslint/no-explicit-any
function isBoolean(value) {
  return typeof value === 'boolean';
}

// eslint-disable-next-line @typescript-eslint/no-explicit-any
function isObject(value) {
  return _typeof(value) === 'object' && value !== null;
}

function _templateObject2() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  height: ", "px;\n\n  &::before {\n    content: '';\n    display: block;\n    width: ", "px;\n    height: ", "px;\n    border: ", "px solid ", ";\n    border-right-color: transparent;\n    background-color: transparent;\n    border-radius: 50%;\n    animation: ", " 1.1s infinite linear;\n  }\n"]);

  _templateObject2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1() {
  var data = _taggedTemplateLiteral(["\n  from {\n    transform: rotate(0deg);\n  }\n\n  to {\n    transform: rotate(360deg);\n  }\n"]);

  _templateObject$1 = function _templateObject() {
    return data;
  };

  return data;
}
var loaderAnimation = keyframes(_templateObject$1());
var Loader = styled.div(_templateObject2(), function (props) {
  return props.size || 35;
}, function (props) {
  return props.size ? props.size / 2 : 35;
}, function (props) {
  return props.size ? props.size / 2 : 35;
}, function (props) {
  return props.strokeWidth || 2;
}, function (props) {
  return props.color || 'var(--bg-black-dark)';
}, loaderAnimation);

/* Internal dependencies */

var ButtonType;

(function (ButtonType) {
  ButtonType["Default"] = "default";
  ButtonType["OutLine"] = "outline";
  ButtonType["Link"] = "link";
})(ButtonType || (ButtonType = {}));

var ButtonType$1 = ButtonType;

function _templateObject4() {
  var data = _taggedTemplateLiteral(["\n    padding: 2px 15px;\n    border-radius: 22px;\n\n    &:hover {\n      background-color: var(--bg-black-light);\n    }\n  "]);

  _templateObject4 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3() {
  var data = _taggedTemplateLiteral(["\n  ", "\n"]);

  _templateObject3 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$1() {
  var data = _taggedTemplateLiteral(["\n  display: block;\n  width: 100%;\n  padding: ", "px 0;\n  font-weight: bold;\n  font-size: ", "px;\n  line-height: 18px;\n  color: ", ";\n  border: ", ";\n  border-radius: 5px;\n  background-color: ", ";\n  outline: none;\n  cursor: ", ";\n"]);

  _templateObject2$1 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2() {
  var data = _taggedTemplateLiteral(["\n  padding: 0 14px;\n  margin-bottom: 6px;\n"]);

  _templateObject$2 = function _templateObject() {
    return data;
  };

  return data;
}

function getBackgroundColor(submitting, disabled, style) {
  if (disabled && !submitting) {
    return 'var(--bg-black-light)';
  }

  if (style === ButtonType$1.Link || style === ButtonType$1.OutLine) {
    return 'var(--bg-white-normal)';
  }

  return 'var(--bgtxt-cobalt-normal)';
}

function getFontColor(submitting, disabled, style) {
  if (disabled && !submitting) {
    return 'var(--txt-black-dark)';
  }

  if (style === ButtonType$1.Link || style === ButtonType$1.OutLine) {
    return 'var(--txt-black-darkest)';
  }

  return 'var(--txt-white-normal)';
}

var Wrapper$1 = styled.div(_templateObject$2());
var Button = styled.button(_templateObject2$1(), function (_ref) {
  var buttonType = _ref.buttonType;
  return buttonType === ButtonType$1.Link ? 5 : 8;
}, function (_ref2) {
  var buttonType = _ref2.buttonType;
  return buttonType === ButtonType$1.Link ? 12 : 14;
}, function (_ref3) {
  var disabled = _ref3.disabled,
      submitting = _ref3.submitting,
      buttonType = _ref3.buttonType;
  return getFontColor(submitting, disabled, buttonType);
}, function (_ref4) {
  var buttonType = _ref4.buttonType;
  return buttonType === ButtonType$1.OutLine ? '1px solid var(--bg-black-light)' : 'none';
}, function (_ref5) {
  var disabled = _ref5.disabled,
      submitting = _ref5.submitting,
      buttonType = _ref5.buttonType;
  return getBackgroundColor(submitting, disabled, buttonType);
}, function (_ref6) {
  var submitting = _ref6.submitting,
      disabled = _ref6.disabled;
  return submitting || disabled ? 'not-allowed' : 'pointer';
});
var Label = styled.span(_templateObject3(), function (props) {
  return props.isLink && css(_templateObject4());
});

/* External dependencies */

function Button$1(_ref) {
  var id = _ref.id,
      label = _ref.label,
      style = _ref.style,
      action = _ref.action,
      disabled = _ref.disabled;

  var _useContext = useContext(FormContext),
      submitting = _useContext.submitting,
      submit = _useContext.submit;

  var loaderColor = useMemo(function () {
    if (style === ButtonType$1.Link || style === ButtonType$1.OutLine) {
      return 'var(--bg-black-dark)';
    }

    return 'var(--bdr-white)';
  }, [style]);
  var content = useMemo(function () {
    if (submitting) {
      return React.createElement(Loader, {
        size: style === ButtonType$1.Link ? 14 : 18,
        color: loaderColor
      });
    }

    if (!label) {
      return null;
    }

    return React.createElement(Label, {
      isLink: style === ButtonType$1.Link
    }, label);
  }, [submitting, loaderColor, label, style]);
  var handleOnClick = useCallback(function () {
    if (!isObject(action)) {
      return;
    }

    if (action.type === ActionType$1.URL && isString(action.url)) {
      var w = window.parent || window;
      w.open(action.url, '_blank', 'noopener');
      return;
    }

    if (action.type === ActionType$1.Submit && isString(id)) {
      submit(id);
    }
  }, [submit, id, action]);

  if (!isString(id) || !isString(label)) {
    return null;
  }

  return React.createElement(Wrapper$1, null, React.createElement(Button, {
    onClick: handleOnClick,
    disabled: submitting || isBoolean(disabled) ? disabled : false,
    submitting: submitting,
    buttonType: style
  }, content));
}

/* Internal dependencies */

function _templateObject$3() {
  var data = _taggedTemplateLiteral(["\n  border: none;\n  border-top: 1px solid var(--bdr-black-light);\n  margin: 8px 0;\n"]);

  _templateObject$3 = function _templateObject() {
    return data;
  };

  return data;
}
var Divider = styled.hr(_templateObject$3());

/* External dependencies */

function Divider$1() {
  return React.createElement(Divider, null);
}

/* Internal dependencies */

function useForceUpdate() {
  var _useReducer = useReducer(function (x) {
    return !x;
  }, true),
      _useReducer2 = _slicedToArray(_useReducer, 2),
      forceUpdate = _useReducer2[1];

  return forceUpdate;
}

/* External dependencies */

function useContainer() {
  var containerRef = useContext(ContainerRefContext);
  var forceUpdate = useForceUpdate();
  var container = containerRef ? containerRef.current : null;
  useEffect(function () {
    if (!container) {
      forceUpdate(undefined);
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, []);
  return container;
}

// eslint-disable-next-line @typescript-eslint/no-explicit-any
function isNumber(value) {
  return typeof value === 'number';
}

var TriangelDownImage = "data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20width%3D%228%22%20height%3D%228%22%20viewBox%3D%220%200%208%208%22%3E%20%20%20%20%3Cpath%20fill%3D%22%23242428%22%20fill-rule%3D%22evenodd%22%20d%3D%22M3.802%207.413L.06%202.923A.258.258%200%200%201%20.258%202.5h7.484c.218%200%20.337.255.198.423l-3.742%204.49a.257.257%200%200%201-.396%200%22%2F%3E%3C%2Fsvg%3E";

var TriangelUpImage = "data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20width%3D%228%22%20height%3D%228%22%20viewBox%3D%220%200%208%208%22%3E%20%20%20%20%3Cpath%20fill%3D%22%23242428%22%20fill-rule%3D%22evenodd%22%20d%3D%22M3.802%201.587L.06%206.077a.258.258%200%200%200%20.198.423h7.484a.258.258%200%200%200%20.198-.423l-3.742-4.49a.257.257%200%200%200-.396%200%22%2F%3E%3C%2Fsvg%3E";

function _templateObject2$2() {
  var data = _taggedTemplateLiteral(["\n  overflow: hidden;\n  text-overflow: ellipsis;\n  white-space: nowrap;\n"]);

  _templateObject2$2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$4() {
  var data = _taggedTemplateLiteral(["\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n"]);

  _templateObject$4 = function _templateObject() {
    return data;
  };

  return data;
}
var absoluteCenter = css(_templateObject$4());
var ellipsis = css(_templateObject2$2());

function _templateObject9() {
  var data = _taggedTemplateLiteral(["\n  color: var(--bgtxt-orange-normal);\n  font-size: 13px;\n  font-weight: bold;\n  line-height: 18px;\n  margin-top: 4px;\n  margin-left: 5px;\n"]);

  _templateObject9 = function _templateObject9() {
    return data;
  };

  return data;
}

function _templateObject8() {
  var data = _taggedTemplateLiteral(["\n  background-color: ", ";\n  height: 32px;\n  padding: 7px 16px;\n  font-size: 14px;\n  line-height: 18px;\n  font-weight: normal;\n  cursor: pointer;\n  ", "\n\n  &:hover {\n    background-color: var(--bg-black-light);\n  }\n"]);

  _templateObject8 = function _templateObject8() {
    return data;
  };

  return data;
}

function _templateObject7() {
  var data = _taggedTemplateLiteral(["\n    top: 33px;\n  "]);

  _templateObject7 = function _templateObject7() {
    return data;
  };

  return data;
}

function _templateObject6() {
  var data = _taggedTemplateLiteral(["\n    bottom: 33px;\n  "]);

  _templateObject6 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5() {
  var data = _taggedTemplateLiteral(["\n  width: 100%;\n  background-color: var(--bg-white-normal);\n  padding: 8px 0;\n  position: absolute;\n  z-index: 10;\n  max-height: 345px;\n  overflow-y: auto;\n  border-radius: 8px;\n  box-shadow: 0 4px 12px 0 var(--shdw-large), 0 0 0 1px var(--shdw-base);\n  ", "\n"]);

  _templateObject5 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$1() {
  var data = _taggedTemplateLiteral(["\n  flex: 1 1 auto;\n  color: ", ";\n"]);

  _templateObject4$1 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$1() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  align-items: center;\n  height: 30px;\n  padding: 5px 8px;\n  font-size: 14px;\n  line-height: 18px;\n  background-color: ", ";\n  color: var(--txt-black-dark);\n  border: solid 1px ", ";\n  border-radius: 3px;\n  cursor: ", ";\n\n  &:hover {\n    border-color: ", ";\n  }\n"]);

  _templateObject3$1 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$3() {
  var data = _taggedTemplateLiteral(["\n  margin: 0 14px;\n"]);

  _templateObject2$3 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$5() {
  var data = _taggedTemplateLiteral(["\n  position: relative;\n  margin-bottom: 8px;\n"]);

  _templateObject$5 = function _templateObject() {
    return data;
  };

  return data;
}
var Wrapper$2 = styled.div(_templateObject$5());
var Content = styled.div(_templateObject2$3());
var Select = styled.div(_templateObject3$1(), function (props) {
  return props.disabled ? 'var(--bg-black-light)' : 'var(--bg-white-normal)';
}, function (props) {
  return props.hasError ? 'var(--bgtxt-orange-normal)' : 'var(--bdr-black-light)';
}, function (props) {
  return props.disabled ? 'not-allowed' : 'pointer';
}, function (props) {
  return props.disabled ? 'var(--bdr-black-light)' : 'var(--bgtxt-cobalt-normal)';
});
var Label$1 = styled.span(_templateObject4$1(), function (_ref) {
  var disabled = _ref.disabled,
      unselected = _ref.unselected;
  return disabled || unselected ? 'var(--txt-black-dark)' : 'var(--txt-black-darkest)';
});
var OptionWrapper = styled.div(_templateObject5(), function (props) {
  return props.toTop ? css(_templateObject6()) : css(_templateObject7());
});
var OptionItem = styled.div(_templateObject8(), function (props) {
  return props.selected ? 'var(--bg-black-light)' : 'var(--bg-white-normal)';
}, ellipsis);
var Error = styled.span(_templateObject9());

function Dropdown(_ref) {
  var id = _ref.id,
      label = _ref.label,
      value = _ref.value,
      items = _ref.items,
      error = _ref.error,
      disabled = _ref.disabled;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      show = _useState2[0],
      setShow = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      toTop = _useState4[0],
      setToTop = _useState4[1];

  var _useState5 = useState(false),
      _useState6 = _slicedToArray(_useState5, 2),
      hasError = _useState6[0],
      setHasError = _useState6[1];

  var wrapperRef = useRef(null);
  var targetRef = useRef(null);
  var optionRef = useRef(null);
  var container = useContainer();

  var _useContext = useContext(FormContext),
      values = _useContext.values,
      submitting = _useContext.submitting,
      updateInput = _useContext.updateInput,
      removeInput = _useContext.removeInput;

  useEffect(function () {
    if (isString(id) && (isString(value) || isNumber(value))) {
      updateInput(id, value);
    }

    var handleOnClickDocument = function handleOnClickDocument(event) {
      if (wrapperRef.current && !wrapperRef.current.contains(event.target)) {
        setShow(false);
      }
    };

    document.addEventListener('mousedown', handleOnClickDocument);
    return function () {
      document.removeEventListener('mousedown', handleOnClickDocument);

      if (isString(id)) {
        removeInput(id);
      }
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  useEffect(function () {
    if (isString(error) && error) {
      setHasError(true);
    }
  }, [error]);
  var selectedId = useMemo(function () {
    if (isString(id)) {
      var contextValue = values[id];

      if (isString(contextValue) || isNumber(contextValue)) {
        return contextValue;
      }
    }

    if (isString(value) || isNumber(value)) {
      return value;
    }

    return undefined;
  }, [values, id, value]);
  var handleOnClick = useCallback(function () {
    if (submitting || !container || !targetRef.current) {
      return;
    }

    if (show) {
      setShow(false);
      return;
    }

    var containerRect = container.getBoundingClientRect();
    var targetRect = targetRef.current.getBoundingClientRect();
    var topSpaceHeight = targetRect.top - containerRect.top;
    var bottomSpaceHeight = containerRect.bottom - targetRect.bottom;
    var isTopSpaceBigger = topSpaceHeight > bottomSpaceHeight;
    setToTop(isTopSpaceBigger);
    setShow(true);
  }, [show, container, submitting]);
  var handleOnClickItem = useCallback(function (optionID) {
    setHasError(false);
    setShow(false);

    if (optionID === selectedId) {
      removeInput(id);
      return;
    }

    updateInput(id, optionID);
  }, [id, selectedId, removeInput, updateInput]);
  var optionItems = useMemo(function () {
    if (!Array.isArray(items)) return null;
    return items.map(function (option) {
      if (!isObject(option) || !isString(option.id) || !isString(option.label)) {
        return null;
      }

      return React.createElement(OptionItem, {
        key: option.id,
        onClick: function onClick() {
          return handleOnClickItem(option.id);
        },
        selected: option.id === selectedId
      }, option.label);
    });
  }, [items, handleOnClickItem, selectedId]);
  var Options = useMemo(function () {
    if (!show) return null;
    return React.createElement(OptionWrapper, {
      ref: optionRef,
      toTop: toTop
    }, optionItems);
  }, [show, optionItems, toTop]);
  var isDisabled = useMemo(function () {
    return submitting || (isBoolean(disabled) ? disabled : false);
  }, [submitting, disabled]);
  var Label = useMemo(function () {
    if (isString(id) && isString(values[id])) {
      var selectedItem = items && items.find(function (item) {
        return item.id === values[id];
      });

      if (selectedItem && isObject(selectedItem) && isString(selectedItem.label)) {
        return React.createElement(Label$1, {
          disabled: isDisabled
        }, selectedItem.label);
      }
    }

    return React.createElement(Label$1, {
      unselected: true,
      disabled: isDisabled
    }, label);
  }, [values, items, label, id, isDisabled]);
  var arrowImage = useMemo(function () {
    return show ? TriangelUpImage : TriangelDownImage;
  }, [show]);

  if (!isString(id) || !isString(label)) {
    return null;
  }

  return React.createElement(Wrapper$2, {
    ref: wrapperRef
  }, React.createElement(Content, null, React.createElement(Select, {
    ref: targetRef,
    onClick: handleOnClick,
    disabled: isDisabled,
    hasError: hasError
  }, Label, React.createElement("img", {
    src: arrowImage,
    alt: "dropdown arrow"
  })), hasError && React.createElement(Error, null, error)), Options);
}

/* Internal dependencies */

function _templateObject4$2() {
  var data = _taggedTemplateLiteral(["\n  color: var(--bgtxt-orange-normal);\n  font-size: 13px;\n  font-weight: bold;\n  line-height: 18px;\n  margin-top: 4px;\n  margin-left: ", "px;\n"]);

  _templateObject4$2 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$2() {
  var data = _taggedTemplateLiteral(["\n  font-family: inherit;\n  width: 100%;\n  height: 30px;\n  padding: 5px 8px;\n  border: solid 1px ", ";\n  border-radius: 3px;\n  font-size: 14px;\n  line-height: 18px;\n  color: ", ";\n  background-color: ", ";\n  outline: none;\n  box-shadow: none;\n  appearance: none;\n\n  &::placeholder {\n    color: var(--txt-black-dark);\n  }\n\n  &:focus {\n    border-color: var(--bgtxt-cobalt-normal);\n  }\n"]);

  _templateObject3$2 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$4() {
  var data = _taggedTemplateLiteral(["\n  display: block;\n  color: var(--txt-black-darkest);\n  font-size: 13px;\n  font-weight: bold;\n  line-height: 18px;\n  margin-bottom: 3px;\n  margin-left: ", "px;\n"]);

  _templateObject2$4 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$6() {
  var data = _taggedTemplateLiteral(["\n  padding: 0 14px;\n  margin-bottom: 6px;\n"]);

  _templateObject$6 = function _templateObject() {
    return data;
  };

  return data;
}
var TEXT_LEFT_MARGIN = 3;
var Wrapper$3 = styled.div(_templateObject$6());
var Label$2 = styled.label(_templateObject2$4(), TEXT_LEFT_MARGIN);
var Input = styled.input(_templateObject3$2(), function (props) {
  return props.hasError ? 'var(--bgtxt-orange-normal)' : 'var(--bdr-black-light)';
}, function (props) {
  return props.disabled ? 'var(--bg-grey-dark)' : 'var(--bg-grey-darkest)';
}, function (props) {
  return props.disabled ? 'var(--bg-black-light)' : 'var(--bg-white-normal)';
});
var Error$1 = styled.span(_templateObject4$2(), TEXT_LEFT_MARGIN);

function Input$1(_ref) {
  var id = _ref.id,
      value = _ref.value,
      label = _ref.label,
      placeholder = _ref.placeholder,
      disabled = _ref.disabled,
      error = _ref.error;

  var _useContext = useContext(FormContext),
      removeInput = _useContext.removeInput,
      updateInput = _useContext.updateInput,
      values = _useContext.values,
      submitting = _useContext.submitting;

  useEffect(function () {
    if (isString(id) && (isString(value) || isNumber(value))) {
      updateInput(id, value);
    }

    return function () {
      if (isString(id)) {
        removeInput(id);
      }
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      hasError = _useState2[0],
      setHasError = _useState2[1];

  useEffect(function () {
    if (isString(error) && error) {
      setHasError(true);
    }
  }, [error]);
  var inputValue = useMemo(function () {
    if (isString(id)) {
      var contextValue = values[id];

      if (isString(contextValue) || isNumber(contextValue)) {
        return contextValue;
      }
    }

    if (isString(value) || isNumber(value)) {
      return value;
    }

    return undefined;
  }, [values, id, value]);
  var handleOnChange = useCallback(function (event) {
    updateInput(id, event.target.value);
    setHasError(false);
  }, [updateInput, id]);
  if (!isString(id)) return null;
  return React.createElement(Wrapper$3, null, label && React.createElement(Label$2, null, label), React.createElement(Input, {
    onChange: handleOnChange,
    value: inputValue,
    placeholder: placeholder,
    disabled: submitting || (isBoolean(disabled) ? disabled : false),
    hasError: hasError
  }), hasError && React.createElement(Error$1, null, error));
}

/* Internal dependencies */

function _templateObject2$5() {
  var data = _taggedTemplateLiteral(["\n  display: block;\n  width: 100%;\n  height: auto;\n  border-radius: 5px;\n  overflow: hidden;\n"]);

  _templateObject2$5 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$7() {
  var data = _taggedTemplateLiteral(["\n  padding: 0 14px;\n  margin: 6px 0;\n"]);

  _templateObject$7 = function _templateObject() {
    return data;
  };

  return data;
}
var Wrapper$4 = styled.div(_templateObject$7());
var Image = styled.img(_templateObject2$5());

/* External dependencies */

function Image$1(_ref) {
  var url = _ref.url;

  if (!isString(url)) {
    return null;
  }

  return React.createElement(Wrapper$4, null, React.createElement(Image, {
    src: url
  }));
}

/* Internal dependencies */

function _templateObject4$3() {
  var data = _taggedTemplateLiteral(["\n  font-size: 14px;\n  line-height: 18px;\n  color: var(--txt-black-darkest);\n  text-overflow: ellipsis;\n  white-space: nowrap;\n  overflow: hidden;\n"]);

  _templateObject4$3 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$3() {
  var data = _taggedTemplateLiteral(["\n  font-size: 12px;\n  font-weight: bold;\n  line-height: 18px;\n  color: var(--txt-black-dark);\n  margin-right: 8px;\n  text-overflow: ellipsis;\n  white-space: nowrap;\n  overflow: hidden;\n"]);

  _templateObject3$3 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$6() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  align-items: center;\n  padding: 5px 14px;\n"]);

  _templateObject2$6 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$8() {
  var data = _taggedTemplateLiteral(["\n  margin-bottom: 6px;\n"]);

  _templateObject$8 = function _templateObject() {
    return data;
  };

  return data;
}
var Wrapper$5 = styled.div(_templateObject$8());
var Item = styled.div(_templateObject2$6());
var Key = styled.span(_templateObject3$3());
var Value = styled.span(_templateObject4$3());

/* External dependencies */

function KeyValue(_ref) {
  var items = _ref.items;

  if (!Array.isArray(items)) {
    return null;
  }

  if (!items.length) {
    return null;
  }

  var content = items.map(function (_ref2) {
    var key = _ref2.key,
        value = _ref2.value;
    var title = isString(key) || isNumber(key) ? key : '';
    var description = isString(value) || isNumber(value) ? value : '';
    return React.createElement(Item, {
      key: title
    }, React.createElement(Key, null, title), React.createElement(Value, null, description));
  });
  return React.createElement(Wrapper$5, null, content);
}

/* Internal dependencies */

function _templateObject5$1() {
  var data = _taggedTemplateLiteral(["\n  flex: none;\n  margin-right: 12px;\n  width: 40px;\n  height: 40px;\n  border-radius: 5px;\n  background-repeat: no-repeat;\n  background-size: cover;\n  background-image: url(", ");\n"]);

  _templateObject5$1 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$4() {
  var data = _taggedTemplateLiteral(["\n  display: -webkit-box;\n  padding: 0;\n  margin: 0;\n  font-size: 12px;\n  color: var(--txt-black-dark);\n  line-height: ", "px;\n  max-height: ", "px;\n  overflow-y: hidden;\n  -webkit-box-orient: vertical;\n  -webkit-line-clamp: ", ";\n"]);

  _templateObject4$4 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$4() {
  var data = _taggedTemplateLiteral(["\n  display: -webkit-box;\n  padding: 0;\n  margin: 0;\n  font-size: 13px;\n  word-break: break-word;\n  color: var(--txt-black-darkest);\n  line-height: ", "px;\n  max-height: ", "px;\n  overflow-y: hidden;\n  -webkit-box-orient: vertical;\n  -webkit-line-clamp: ", ";\n"]);

  _templateObject3$4 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$7() {
  var data = _taggedTemplateLiteral(["\n  flex: 1 1 auto;\n"]);

  _templateObject2$7 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$9() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  padding: 7px 14px;\n  transition: background-color ease-in-out .15s;\n  cursor: ", ";\n\n  &:hover {\n    background-color: var(--bg-black-light);\n  }\n"]);

  _templateObject$9 = function _templateObject() {
    return data;
  };

  return data;
}
var LINE_HEIGHT = 18;
var TITLE_MAX_LINE = 2;
var DESCRIPTION_MAX_LINE = 1;

function getWrapperCursor(_ref) {
  var disabled = _ref.disabled,
      active = _ref.active;

  if (disabled) {
    return 'not-allowed';
  }

  if (active) {
    return 'pointer';
  }

  return 'default';
}

var Wrapper$6 = styled.div(_templateObject$9(), function (props) {
  return getWrapperCursor(props);
});
var Content$1 = styled.div(_templateObject2$7());
/* stylelint-disable value-no-vendor-prefix, property-no-vendor-prefix */

var Title = styled.p(_templateObject3$4(), LINE_HEIGHT, LINE_HEIGHT * TITLE_MAX_LINE, TITLE_MAX_LINE);
var Description = styled.p(_templateObject4$4(), LINE_HEIGHT, LINE_HEIGHT * DESCRIPTION_MAX_LINE, DESCRIPTION_MAX_LINE);
/* stylelint-enable value-no-vendor-prefix, property-no-vendor-prefix */

var Image$2 = styled.div(_templateObject5$1(), function (props) {
  return props.src;
});

/* External dependencies */

function ListItem(_ref) {
  var id = _ref.id,
      title = _ref.title,
      description = _ref.description,
      image = _ref.image,
      action = _ref.action;

  var _useContext = useContext(FormContext),
      submit = _useContext.submit,
      submitting = _useContext.submitting;

  var hasUrl = useMemo(function () {
    if (!isObject(action)) return false;
    if (!isString(action.type) || action.type !== ActionType$1.URL) return false;
    if (!isString(action.url) || !action.url) return false;
    return true;
  }, [action]);
  var hasSubmit = useMemo(function () {
    if (!isObject(action)) return false;
    if (!isString(action.type) || action.type !== ActionType$1.Submit) return false;
    return true;
  }, [action]);
  var handleOnClick = useCallback(function () {
    if (hasUrl) {
      var w = window.parent || window;
      w.open(action.url, '_blank', 'noopener noreferrer');
      return;
    }

    if (hasSubmit && !submitting) {
      submit(id);
    }
  }, [hasUrl, hasSubmit, id, action, submit, submitting]);
  var Image = useMemo(function () {
    if (!isString(image) || !image) {
      return null;
    }

    return React.createElement(Image$2, {
      src: image
    });
  }, [image]);
  var Description$1 = useMemo(function () {
    if (!isString(description) || !description) {
      return null;
    }

    return React.createElement(Description, null, description);
  }, [description]);

  if (!isString(title) || !title || !isString(id) || !id) {
    return null;
  }

  return React.createElement(Wrapper$6, {
    active: hasUrl || hasSubmit,
    onClick: handleOnClick,
    disabled: submitting
  }, Image, React.createElement(Content$1, null, React.createElement(Title, null, title), Description$1));
}

function _templateObject$a() {
  var data = _taggedTemplateLiteral(["\n  margin-bottom: 6px;\n"]);

  _templateObject$a = function _templateObject() {
    return data;
  };

  return data;
}
var Wrapper$7 = styled.div(_templateObject$a());

function List(_ref) {
  var items = _ref.items;

  if (!Array.isArray(items)) {
    return null;
  }

  return React.createElement(Wrapper$7, null, items.map(function (item) {
    if (!isObject(item)) {
      return null;
    }

    if (!isString(item.id)) {
      return null;
    }

    return React.createElement(ListItem, _extends({}, item, {
      key: item.id
    }));
  }));
}

function _templateObject$b() {
  var data = _taggedTemplateLiteral(["\n  width: 100%;\n  height: ", ";\n"]);

  _templateObject$b = function _templateObject() {
    return data;
  };

  return data;
}

function getHeight(size) {
  switch (size) {
    case 'xs':
      return '4px';

    case 's':
      return '8px';

    case 'm':
      return '16px';

    case 'l':
      return '24px';

    default:
      return '4px';
  }
}

var Spacer = styled.div(_templateObject$b(), function (props) {
  return getHeight(props.size);
});

/* External dependencies */

function Spacer$1(_ref) {
  var size = _ref.size;
  return React.createElement(Spacer, {
    size: size
  });
}

var TextColors;

(function (TextColors) {
  TextColors["Defult"] = "default";
  TextColors["Muted"] = "muted";
  TextColors["Success"] = "success";
  TextColors["Highlighted"] = "highlighted";
  TextColors["Warning"] = "warning";
})(TextColors || (TextColors = {}));

var TextColors$1 = TextColors;

var TextStyles;

(function (TextStyles) {
  TextStyles["H1"] = "h1";
  TextStyles["H2"] = "h2";
  TextStyles["Paragraph"] = "paragraph";
})(TextStyles || (TextStyles = {}));

var TextStyles$1 = TextStyles;

function _templateObject$c() {
  var data = _taggedTemplateLiteral(["\n  font-size: ", "px;\n  font-weight: ", ";\n  color: ", ";\n  white-space: pre-line;\n  text-align: ", ";\n  padding: 0 14px;\n  margin-top: ", "px;\n  margin-bottom: ", "px;\n"]);

  _templateObject$c = function _templateObject() {
    return data;
  };

  return data;
}
var SUPPORTED_ALIGN = ['center', 'left', 'right'];

function getFontSize(style) {
  switch (style) {
    case TextStyles$1.H1:
      return 18;

    case TextStyles$1.H2:
    case TextStyles$1.Paragraph:
    default:
      return 12;
  }
}

function getFontWeight(style) {
  switch (style) {
    case TextStyles$1.H1:
    case TextStyles$1.H2:
      return 'bold';

    default:
      return 'normal';
  }
}

function getFontColor$1(color) {
  switch (color) {
    case TextColors$1.Muted:
      return 'var(--txt-black-dark)';

    case TextColors$1.Success:
      return 'var(--bgtxt-green-normal)';

    case TextColors$1.Highlighted:
      return 'var(--bgtxt-cobalt-normal)';

    case TextColors$1.Warning:
      return 'var(--bgtxt-orange-normal)';

    default:
      return 'var(--txt-black-darkest)';
  }
}

function getAlign(align) {
  if (SUPPORTED_ALIGN.includes(align)) {
    return align;
  }

  return 'left';
}

function getMarginTop(style) {
  switch (style) {
    case TextStyles$1.H1:
      return 6;

    case TextStyles$1.H2:
    case TextStyles$1.Paragraph:
    default:
      return 4;
  }
}

function getMarginBottom(style) {
  switch (style) {
    case TextStyles$1.H1:
      return 6;

    case TextStyles$1.H2:
    case TextStyles$1.Paragraph:
    default:
      return 3;
  }
}

var Text = styled.div(_templateObject$c(), function (props) {
  return getFontSize(props.textStyle);
}, function (props) {
  return getFontWeight(props.textStyle);
}, function (props) {
  return getFontColor$1(props.textColor);
}, function (props) {
  return getAlign(props.align);
}, function (props) {
  return getMarginTop(props.textStyle);
}, function (props) {
  return getMarginBottom(props.textStyle);
});

/* External dependencies */

function Text$1(_ref) {
  var text = _ref.text,
      style = _ref.style,
      color = _ref.color,
      align = _ref.align;

  if (!isString(text) && !isNumber(text)) {
    return null;
  }

  return React.createElement(Text, {
    textStyle: style,
    textColor: color,
    align: align
  }, text);
}

/* Internal dependencies */

function isNil(value) {
  return value === null || value === undefined || typeof value === 'undefined';
}

function isEmpty(value) {
  if (isNil(value)) {
    return true;
  }

  if (Array.isArray(value) || isString(value)) {
    return value.length === 0;
  }

  if (isObject(value)) {
    return Object.keys(value).length === 0;
  }

  return false;
}

function leadingZero(n) {
  return n < 10 ? "0".concat(n) : "".concat(n);
}

function toDateString(value) {
  var _date = isNumber(value) ? new Date(value) : value;

  return [_date.getFullYear(), leadingZero(_date.getMonth() + 1), leadingZero(_date.getDate())].join('-');
}

/* Internal dependencies */
function Values(object) {
  if (!object) {
    return [];
  } // @ts-ignore


  return Object.keys(object).map(function (k) {
    return object[k];
  });
}

var _EventColorMap, _EventColorBorderMap;
var EventColor;

(function (EventColor) {
  EventColor["White"] = "white";
  EventColor["Blue"] = "blue";
  EventColor["Cobalt"] = "cobalt";
  EventColor["Orange"] = "orange";
  EventColor["Red"] = "red";
  EventColor["Green"] = "green";
})(EventColor || (EventColor = {}));

var EventColor$1 = EventColor;
var values = Values(EventColor);
var EventColorMap = (_EventColorMap = {}, _defineProperty(_EventColorMap, EventColor.White, 'var(--bg-white-normal)'), _defineProperty(_EventColorMap, EventColor.Blue, 'var(--bgtxt-blue-normal)'), _defineProperty(_EventColorMap, EventColor.Cobalt, 'var(--bgtxt-cobalt-normal)'), _defineProperty(_EventColorMap, EventColor.Orange, 'var(--bgtxt-orange-normal)'), _defineProperty(_EventColorMap, EventColor.Red, 'var(--bgtxt-red-normal)'), _defineProperty(_EventColorMap, EventColor.Green, 'var(--bgtxt-green-normal)'), _EventColorMap);
var EventColorBorderMap = (_EventColorBorderMap = {}, _defineProperty(_EventColorBorderMap, EventColor.White, 'var(--bg-black-dark)'), _defineProperty(_EventColorBorderMap, EventColor.Blue, 'var(--bgtxt-blue-normal)'), _defineProperty(_EventColorBorderMap, EventColor.Cobalt, 'var(--bgtxt-cobalt-normal)'), _defineProperty(_EventColorBorderMap, EventColor.Orange, 'var(--bgtxt-orange-normal)'), _defineProperty(_EventColorBorderMap, EventColor.Red, 'var(--bgtxt-red-normal)'), _defineProperty(_EventColorBorderMap, EventColor.Green, 'var(--bgtxt-green-normal)'), _EventColorBorderMap);
function getBackgroundColor$1() {
  var preferredColor = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : EventColor.White;
  return EventColorMap[preferredColor] || EventColorMap[EventColor.White];
}
function getBorderColor() {
  var preferredColor = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : EventColor.White;
  return EventColorBorderMap[preferredColor] || EventColorBorderMap[EventColor.White];
}

function _templateObject4$5() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  align-items: center;\n  flex-direction: row;\n  height: ", "px;\n  padding: 5px 6px;\n\n  &:not(:first-child) {\n    ", " {\n      &::before {\n        ", "\n        top: 0;\n        width: 2px;\n        height: ", "px;\n        background-color: var(--bg-black-light);\n        content: '';\n      }\n    }\n  }\n"]);

  _templateObject4$5 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$5() {
  var data = _taggedTemplateLiteral(["\n  ", "\n  flex: 1 1 auto;\n  font-size: 14px;\n  line-height: 18px;\n  color: var(--txt-black-darkest);\n"]);

  _templateObject3$5 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$8() {
  var data = _taggedTemplateLiteral(["\n  ", "\n  font-size: 12px;\n  font-weight: bold;\n  line-height: 16px;\n  color: var(--txt-black-dark);\n"]);

  _templateObject2$8 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$d() {
  var data = _taggedTemplateLiteral(["\n  position: relative;\n  width: ", "px;\n  height: ", "px;\n  min-width: ", "px;\n  min-height: ", "px;\n\n  &::after {\n    ", "\n    width: ", "px;\n    height: ", "px;\n    background-color: ", ";\n    border-radius: 50%;\n    border: solid 2px ", ";\n    content: '';\n    z-index: 2;\n  }\n"]);

  _templateObject$d = function _templateObject() {
    return data;
  };

  return data;
}
var EventItemHeight = 28;
var MarkWrapperSize = 24;
var MarkSize = 8;
var Mark = styled.div(_templateObject$d(), MarkWrapperSize, MarkWrapperSize, MarkWrapperSize, MarkWrapperSize, absoluteCenter, MarkSize, MarkSize, function (props) {
  return getBackgroundColor$1(props.color);
}, function (props) {
  return getBorderColor(props.color);
});
var Time = styled.div(_templateObject2$8(), function (props) {
  return props.hour24 ? "\n    width: 40px;\n    min-width: 40px;\n  " : "\n    width: 66px;\n    min-width: 66px;\n  ";
});
var Value$1 = styled.div(_templateObject3$5(), ellipsis);
var Wrapper$8 = styled.div(_templateObject4$5(), EventItemHeight, Mark, absoluteCenter, EventItemHeight);

/* External dependencies */

function TimelineEventItem(_ref) {
  var date = _ref.date,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? EventColor$1.White : _ref$color,
      _ref$hour = _ref.hour24,
      hour24 = _ref$hour === void 0 ? false : _ref$hour,
      children = _ref.children;
  var formattedTime = useMemo(function () {
    var result = [];

    if (date && date instanceof Date) {
      if (hour24) {
        result.push(leadingZero(date.getHours()));
      } else {
        result.push(date.getHours() > 12 ? "".concat(leadingZero(date.getHours() - 12)) : leadingZero(date.getHours()));
      }

      result.push(':');
      result.push(date.getMinutes() < 10 ? "0".concat(date.getMinutes()) : "".concat(date.getMinutes()));

      if (!hour24) {
        result.push(date.getHours() >= 12 ? ' PM' : ' AM');
      }
    }

    return result.join('');
  }, [date, hour24]);
  return React.createElement(Wrapper$8, null, React.createElement(Mark, {
    color: color
  }), React.createElement(Time, {
    hour24: hour24
  }, formattedTime), React.createElement(Value$1, null, children));
}

function _templateObject3$6() {
  var data = _taggedTemplateLiteral(["\n  font-size: 13px;\n  font-weight: bold;\n  line-height: 16px;\n  color: var(--txt-black-dark);\n  cursor: pointer;\n\n  &::after {\n    position: absolute;\n    box-sizing: border-box;\n    z-index: 3;\n    top: 100%;\n    left: 14px;\n    min-height: 36px;\n    padding: 9px 14px;\n    border-radius: 6px;\n    backdrop-filter: blur(20px);\n    box-shadow: 0 4px 20px 0 var(--shdw-large), 0 0 2px 0 var(--shdw-base);\n    background-color: var(--inverted-bg-white-low);\n    font-size: 14px;\n    line-height: 18px;\n    color: var(--txt-white-normal);\n    opacity: 0;\n    pointer-events: none;\n    content: attr(data-groupid);\n    transition: opacity .1s cubic-bezier(.72, .36, .09, .99) .5s;\n  }\n\n  &:hover {\n    &::after {\n      opacity: 1;\n    }\n  }\n"]);

  _templateObject3$6 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$9() {
  var data = _taggedTemplateLiteral(["\n  position: relative;\n  display: flex;\n  align-items: center;\n  flex-direction: row;\n  height: 24px;\n  padding: 0 14px;\n"]);

  _templateObject2$9 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$e() {
  var data = _taggedTemplateLiteral(["\n  padding: 8px 0;\n"]);

  _templateObject$e = function _templateObject() {
    return data;
  };

  return data;
}
var Wrapper$9 = styled.div(_templateObject$e());
var GroupLabel = styled.div(_templateObject2$9());
var GroupLabelContent = styled.span(_templateObject3$6());

function Timeline(_ref) {
  var events = _ref.events,
      _ref$hour = _ref.hour24,
      hour24 = _ref$hour === void 0 ? false : _ref$hour;
  var eventItems = useMemo(function () {
    if (!Array.isArray(events) || isEmpty(events)) {
      return {};
    }

    var _mapped = events.filter(function (event) {
      return !isNil(event.ts) && isNumber(event.ts) && !isEmpty(event.value);
    }).sort(function (event1, event2) {
      if (event1.ts < event2.ts) {
        return 1;
      }

      if (event1.ts > event2.ts) {
        return -1;
      }

      return 0;
    }).map(function (event) {
      return {
        key: "".concat(event.ts),
        date: new Date(event.ts),
        value: event.value,
        color: event.color,
        hour24: hour24
      };
    });

    return _mapped.reduce(function (result, event) {
      var dateString = toDateString(event.date);

      if (!isEmpty(result[dateString])) {
        result[dateString].push(event);
      } else {
        result[dateString] = [];
        result[dateString].push(event);
      }

      return result;
    }, {});
  }, [events, hour24]);
  var makeLabel = useCallback(function (label) {
    var TODAY = new Date();
    var TODAY_STRING = toDateString(TODAY);
    var YESTERDAY_STRING = toDateString(new Date().setDate(TODAY.getDate() - 1));

    if (label === TODAY_STRING) {
      return 'Today';
    }

    if (label === YESTERDAY_STRING) {
      return 'Yesterday';
    }

    return label;
  }, []);
  var TimelineContentComponent = useMemo(function () {
    return Object.keys(eventItems).map(function (label) {
      return React.createElement("div", {
        key: label
      }, React.createElement(GroupLabel, null, React.createElement(GroupLabelContent, {
        "data-groupid": label
      }, makeLabel(label))), React.createElement("div", null, eventItems[label].map(function (_ref2) {
        var key = _ref2.key,
            value = _ref2.value,
            others = _objectWithoutProperties(_ref2, ["key", "value"]);

        return React.createElement(TimelineEventItem, _extends({
          key: key
        }, others), value);
      })));
    });
  }, [makeLabel, eventItems]);

  if (isEmpty(eventItems)) {
    return null;
  }

  return React.createElement(Wrapper$9, null, TimelineContentComponent);
}

var ComponentType;

(function (ComponentType) {
  ComponentType["Button"] = "button";
  ComponentType["Divider"] = "divider";
  ComponentType["Dropdown"] = "dropdown";
  ComponentType["Image"] = "image";
  ComponentType["Input"] = "input";
  ComponentType["KeyValue"] = "key-value";
  ComponentType["List"] = "list";
  ComponentType["ListItem"] = "list-item";
  ComponentType["Spacer"] = "spacer";
  ComponentType["Text"] = "text";
  ComponentType["Timeline"] = "timeline";
  ComponentType["TimelineEventItem"] = "timeline-event-item";
})(ComponentType || (ComponentType = {}));

var ComponentType$1 = ComponentType;

function getComponent(type) {
  switch (type) {
    case ComponentType$1.Button:
      return Button$1;

    case ComponentType$1.Divider:
      return Divider$1;

    case ComponentType$1.Dropdown:
      return Dropdown;

    case ComponentType$1.Image:
      return Image$1;

    case ComponentType$1.KeyValue:
      return KeyValue;

    case ComponentType$1.List:
      return List;

    case ComponentType$1.ListItem:
      return ListItem;

    case ComponentType$1.Spacer:
      return Spacer$1;

    case ComponentType$1.Input:
      return Input$1;

    case ComponentType$1.Text:
      return Text$1;

    case ComponentType$1.Timeline:
      return Timeline;

    case ComponentType$1.TimelineEventItem:
      return TimelineEventItem;

    default:
      return null;
  }
}

function renderItem(item) {
  if (!isObject(item)) {
    return null;
  }

  var componentType = isString(item.type) ? item.type : undefined;
  var SnippetComponent = getComponent(componentType);

  if (!SnippetComponent) {
    return null;
  }

  var key = isString(item.id) ? item.id : undefined;
  return React.createElement(SnippetComponent, _extends({}, item, {
    id: key,
    key: key
  }));
}

function Snippet(_ref) {
  var items = _ref.items;

  if (!Array.isArray(items)) {
    return null;
  }

  return React.createElement(React.Fragment, null, items.map(renderItem));
}

/* External dependencies */

function Main(_ref) {
  var className = _ref.className,
      submitting = _ref.submitting,
      onSubmit = _ref.onSubmit,
      layout = _ref.layout;
  return React.createElement(ContainerRefProvider, {
    className: className
  }, React.createElement(FormProvider, {
    submitting: submitting,
    onSubmit: onSubmit
  }, React.createElement(Snippet, {
    items: layout
  })));
}

/* Internal dependencies */

/* Internal dependencies */

export default Main;
//# sourceMappingURL=esm.js.map
