/* External dependencies */
import styled, { css } from 'styled-components'

/* Internal dependencies */
import ButtonType from './ButtonType'

interface ButtonProps {
  submitting: boolean
  buttonType?: string
}

interface LabelProps {
  isLink: boolean
}

function getBackgroundColor(submitting: boolean, disabled?: boolean, style?: string) {
  if (disabled && !submitting) {
    return 'var(--bg-black-light)'
  }

  if (style === ButtonType.Link || style === ButtonType.OutLine) {
    return 'var(--bg-white-normal)'
  }

  return 'var(--bgtxt-cobalt-normal)'
}

function getFontColor(submitting: boolean, disabled?: boolean, style?: string) {
  if (disabled && !submitting) {
    return 'var(--txt-black-dark)'
  }

  if (style === ButtonType.Link || style === ButtonType.OutLine) {
    return 'var(--txt-black-darkest)'
  }

  return 'var(--txt-white-normal)'
}

export const Wrapper = styled.div`
  padding: 0 14px;
  margin-bottom: 6px;
`

export const Button = styled.button<ButtonProps>`
  display: block;
  width: 100%;
  padding: ${({ buttonType }) => (buttonType === ButtonType.Link ? 5 : 8)}px 0;
  font-weight: bold;
  font-size: ${({ buttonType }) => (buttonType === ButtonType.Link ? 12 : 14)}px;
  line-height: 18px;
  color: ${({ disabled, submitting, buttonType }) => (getFontColor(submitting, disabled, buttonType))};
  border: ${({ buttonType }) => (buttonType === ButtonType.OutLine ? '1px solid var(--bg-black-light)' : 'none')};
  border-radius: 5px;
  background-color: ${({ disabled, submitting, buttonType }) => (getBackgroundColor(submitting, disabled, buttonType))};
  outline: none;
  cursor: ${({ submitting, disabled }) => ((submitting || disabled) ? 'not-allowed' : 'pointer')};
`

export const Label = styled.span<LabelProps>`
  ${(props) => (props.isLink && css`
    padding: 2px 15px;
    border-radius: 22px;

    &:hover {
      background-color: var(--bg-black-light);
    }
  `)}
`
