/* External dependencies */
import styled, { css } from 'styled-components'

/* Internal dependencies */
import { ellipsis } from '../../styles/Mixins'

interface OptionWrapperProps {
  toTop: boolean
}

interface SelectProps {
  disabled: boolean
  hasError: boolean
}

interface LabelProps {
  unselected?: boolean
  disabled: boolean
}

interface OptionItemProps {
  selected: boolean
}

export const Wrapper = styled.div`
  position: relative;
  margin-bottom: 8px;
`

export const Content = styled.div`
  margin: 0 14px;
`

export const Select = styled.div<SelectProps>`
  display: flex;
  align-items: center;
  height: 30px;
  padding: 5px 8px;
  font-size: 14px;
  line-height: 18px;
  background-color: ${(props) => (props.disabled ? 'var(--bg-black-light)' : 'var(--bg-white-normal)')};
  color: var(--txt-black-dark);
  border: solid 1px ${(props) => (props.hasError ? 'var(--bgtxt-orange-normal)' : 'var(--bdr-black-light)')};
  border-radius: 3px;
  cursor: ${(props) => (props.disabled ? 'not-allowed' : 'pointer')};

  &:hover {
    border-color: ${(props) => (props.disabled ? 'var(--bdr-black-light)' : 'var(--bgtxt-cobalt-normal)')};
  }
`

export const Label = styled.span<LabelProps>`
  flex: 1 1 auto;
  color: ${({ disabled, unselected }) => ((disabled || unselected) ? 'var(--txt-black-dark)' : 'var(--txt-black-darkest)')};
`

export const OptionWrapper = styled.div<OptionWrapperProps>`
  width: 100%;
  background-color: var(--bg-white-normal);
  padding: 8px 0;
  position: absolute;
  z-index: 10;
  max-height: 345px;
  overflow-y: auto;
  border-radius: 8px;
  box-shadow: 0 4px 12px 0 var(--shdw-large), 0 0 0 1px var(--shdw-base);
  ${(props) => (props.toTop ? css`
    bottom: 33px;
  ` : css`
    top: 33px;
  `)}
`

export const OptionItem = styled.div<OptionItemProps>`
  background-color: ${(props) => (props.selected ? 'var(--bg-black-light)' : 'var(--bg-white-normal)')};
  height: 32px;
  padding: 7px 16px;
  font-size: 14px;
  line-height: 18px;
  font-weight: normal;
  cursor: pointer;
  ${ellipsis}

  &:hover {
    background-color: var(--bg-black-light);
  }
`

export const Error = styled.span`
  color: var(--bgtxt-orange-normal);
  font-size: 13px;
  font-weight: bold;
  line-height: 18px;
  margin-top: 4px;
  margin-left: 5px;
`
