/* External dependencies */
import styled from 'styled-components'

interface InputProps {
  hasError: boolean
}

const TEXT_LEFT_MARGIN = 3

export const Wrapper = styled.div`
  padding: 0 14px;
  margin-bottom: 6px;
`

export const Label = styled.label`
  display: block;
  color: var(--txt-black-darkest);
  font-size: 13px;
  font-weight: bold;
  line-height: 18px;
  margin-bottom: 3px;
  margin-left: ${TEXT_LEFT_MARGIN}px;
`

export const Input = styled.input<InputProps>`
  font-family: inherit;
  width: 100%;
  height: 30px;
  padding: 5px 8px;
  border: solid 1px ${(props) => (props.hasError ? 'var(--bgtxt-orange-normal)' : 'var(--bdr-black-light)')};
  border-radius: 3px;
  font-size: 14px;
  line-height: 18px;
  color: ${(props) => (props.disabled ? 'var(--bg-grey-dark)' : 'var(--bg-grey-darkest)')};
  background-color: ${(props) => (props.disabled ? 'var(--bg-black-light)' : 'var(--bg-white-normal)')};
  outline: none;
  box-shadow: none;
  appearance: none;

  &::placeholder {
    color: var(--txt-black-dark);
  }

  &:focus {
    border-color: var(--bgtxt-cobalt-normal);
  }
`

export const Error = styled.span`
  color: var(--bgtxt-orange-normal);
  font-size: 13px;
  font-weight: bold;
  line-height: 18px;
  margin-top: 4px;
  margin-left: ${TEXT_LEFT_MARGIN}px;
`
