/* Internal dependencies */
import _values from '../../utils/values'

enum EventColor {
  White = 'white',
  Blue = 'blue',
  Cobalt = 'cobalt',
  Orange = 'orange',
  Red = 'red',
  Green = 'green',
}

export default EventColor

export const values: string[] = _values(EventColor)

export const EventColorMap: { [key: string]: string } = {
  [EventColor.White]: 'var(--bg-white-normal)',
  [EventColor.Blue]: 'var(--bgtxt-blue-normal)',
  [EventColor.Cobalt]: 'var(--bgtxt-cobalt-normal)',
  [EventColor.Orange]: 'var(--bgtxt-orange-normal)',
  [EventColor.Red]: 'var(--bgtxt-red-normal)',
  [EventColor.Green]: 'var(--bgtxt-green-normal)',
}

export const EventColorBorderMap: { [key: string]: string } = {
  [EventColor.White]: 'var(--bg-black-dark)',
  [EventColor.Blue]: 'var(--bgtxt-blue-normal)',
  [EventColor.Cobalt]: 'var(--bgtxt-cobalt-normal)',
  [EventColor.Orange]: 'var(--bgtxt-orange-normal)',
  [EventColor.Red]: 'var(--bgtxt-red-normal)',
  [EventColor.Green]: 'var(--bgtxt-green-normal)',
}

export function getBackgroundColor(preferredColor: EventColor | string = EventColor.White): string {
  return EventColorMap[preferredColor] || EventColorMap[EventColor.White]
}

export function getBorderColor(preferredColor: EventColor | string = EventColor.White): string {
  return EventColorBorderMap[preferredColor] || EventColorBorderMap[EventColor.White]
}
